@@ -24,15 +24,7 @@
 Handle boilerplate generation for classes.
 """
 import sys
-import warnings
 
-# Import speed optimization
-# The C implementation can import nearly 100x faster
-# and will usually be available.
-try:
-    from _functools import partial
-except ImportError:
-    from functools import partial
 
 # Typing is a slow import so the 'dataclass_transform' code is copied
 # into a separate file. This also provides 3.9/3.10 support without
@@ -57,6 +49,7 @@ from ..sentinels import NOTHING, KW_ONLY
 from .method_generators import (
     init_maker,
     repr_maker,
+    repr_maker_no_eval,
     eq_maker,
     iter_maker,
     prefab_init_maker,
@@ -83,7 +76,6 @@ def attribute(
     *,
     default=NOTHING,
     default_factory=NOTHING,
-    converter=None,  # DEPRECATED
     init=True,
     repr=True,
     kw_only=False,
@@ -93,8 +85,6 @@ def attribute(
     Additional definition for how to generate standard methods
     for an instance attribute.
 
-    **NOTE**: There is currently a `converter` parameter that will be removed in a future version.
-
     :param default: Default value for this attribute
     :param default_factory: 0 argument callable to give a default value
                             (for otherwise mutable defaults, eg: list)
@@ -107,17 +97,9 @@ def attribute(
 
     :return: Attribute generated with these parameters.
     """
-    if converter is not None:
-        warnings.warn(
-            DeprecationWarning(
-                "Converters will be removed in v1.0. "
-                "This behaviour has been replaced by __prefab_post_init__"
-            )
-        )
     return Attribute(
         default=default,
         default_factory=default_factory,
-        converter=converter,
         init=init,
         repr=repr,
         kw_only=kw_only,
@@ -281,7 +263,13 @@ def _make_prefab(
 
     default_defined = []
     valid_fields = []
+
+    use_eval_repr = True
+
     for name, attrib in attributes.items():
+        if use_eval_repr and (attrib.exclude_field or (attrib.init ^ attrib.repr)):
+            use_eval_repr = False
+
         if attrib.exclude_field:
             if name not in post_init_args:
                 raise LivePrefabError(
@@ -312,7 +300,10 @@ def _make_prefab(
     else:
         setattr(cls, "__prefab_init__", prefab_init_maker)
     if repr and "__repr__" not in cls.__dict__:
-        setattr(cls, "__repr__", repr_maker)
+        if use_eval_repr:
+            setattr(cls, "__repr__", repr_maker)
+        else:
+            setattr(cls, "__repr__", repr_maker_no_eval)
     if eq and "__eq__" not in cls.__dict__:
         setattr(cls, "__eq__", eq_maker)
     if iter and "__iter__" not in cls.__dict__:
@@ -366,8 +357,8 @@ def prefab(
         # Called as () method to change defaults
         # Skip compile arguments other than prefab/fallback
         # These are not needed
-        return partial(
-            prefab,
+        return lambda cls_: prefab(
+            cls_,
             init=init,
             repr=repr,
             eq=eq,
